<?php
/*
Plugin Name: Title on Image Alt="" automatically
Plugin URI: https://webdesignerk.com
Description: Este plugin agrega el título del post actual en el campo "alt" de todas las imágenes en el post. Opciones:  Ajustes > Title on Image Alt
Version: 1.0
Author: konstantin K.
Author URI: https://webdesignerk.com
*/



function add_post_title_to_image_alt( $content ) {
    global $post;

    $apply_categories = get_option( 'add_post_title_to_image_alt_categories', array() );

    if ( ! in_category( $apply_categories, $post ) ) {
        return $content;
    }

    $doc = new DOMDocument();
    $doc->loadHTML(mb_convert_encoding($content, 'HTML-ENTITIES', 'UTF-8'));

    $images = $doc->getElementsByTagName( 'img' );

    foreach ( $images as $image ) {
        $alt = $image->getAttribute( 'alt' );
        $title = get_the_title();

        if ( empty( $alt ) ) {
            $image->setAttribute( 'alt', $title );
        } else {
            $image->setAttribute( 'alt', $title . ' - ' . $alt );
        }
    }

    $new_content = $doc->saveHTML();

    return $new_content;
}

add_filter( 'the_content', 'add_post_title_to_image_alt' );
add_filter( 'content_edit_pre', 'add_post_title_to_image_alt' );


function add_post_title_to_image_alt_settings_page() {
    add_submenu_page(
        'options-general.php',
        'Title on Image Alt Settings',
        'Title on Image Alt',
        'manage_options',
        'title-on-image-alt-settings',
        'add_post_title_to_image_alt_settings'
    );
}
add_action( 'admin_menu', 'add_post_title_to_image_alt_settings_page' );







function add_post_title_to_image_alt_settings() {

  // Si el usuario no tiene permisos suficientes, mostrar mensaje de error y salir.
if ( ! current_user_can( 'manage_options' ) ) {
    wp_die( 'You do not have sufficient permissions to access this page.' );
}

// Si se envió el formulario, actualizar la opción de configuración.
if ( isset( $_POST['add_post_title_to_image_alt_categories'] ) ) {
    update_option( 'add_post_title_to_image_alt_categories', $_POST['add_post_title_to_image_alt_categories'] );
    update_option( 'add_post_title_to_image_alt_page', $_POST['add_post_title_to_image_alt_page'] );
    echo '<div class="notice notice-success"><p>Settings updated.</p></div>';
}

// Obtener las categorías seleccionadas actualmente.
$current_categories = get_option( 'add_post_title_to_image_alt_categories', array() );

// Obtener la página seleccionada actualmente.
$current_page = get_option( 'add_post_title_to_image_alt_page', 0 );

// Obtener todas las categorías de WordPress.
$categories = get_categories();

// Obtener todas las páginas de WordPress.
$pages = get_pages();

// Generar el HTML para la página de configuración.
$html = '<div class="wrap">';
$html .= '<h1>Title on Image Alt Settings - Titulo del post en el alt de la imagen automaticamente</h1>';
$html .= '<form method="post">';
$html .= '<table class="form-table">';

$html .= '<p>Puedes segmentar entre paginas y categorías para que el modulo funciona solamente ahi o en todas las paginas</p>';

$html .= '<tr><th>Select Categories:</th><td>';

foreach ( $categories as $category ) {
    $checked = in_array( $category->term_id, $current_categories ) ? 'checked' : '';
    $html .= '<label><input type="checkbox" name="add_post_title_to_image_alt_categories[]" value="' . $category->term_id . '" ' . $checked . '> ' . $category->name . '</label><br>';
}

$html .= '</td></tr>';
$html .= '<tr><th>Select Page:</th><td>';
$html .= '<select name="add_post_title_to_image_alt_page">';
$html .= '<option value="0">All Pages</option>';

foreach ( $pages as $page ) {
    $selected = selected( $page->ID, $current_page, false );
    $html .= '<option value="' . $page->ID . '" ' . $selected . '>' . $page->post_title . '</option>';
}

$html .= '</select>';
$html .= '</td></tr>';
$html .= '</table>';
$html .= '<p><input type="submit" class="button button-primary" value="Save Changes"></p>';
$html .= '</form>';
$html .= '</div>';

echo $html;
}


// Añadir botón de ajustes en la lista de acciones del plugin
function add_post_title_to_image_alt_plugin_action_links( $links ) {
    $settings_link = '<a href="' . esc_url( admin_url( 'options-general.php?page=title-on-image-alt-settings' ) ) . '">' . __( 'Settings', 'add-post-title-to-image-alt' ) . '</a>';
    array_unshift( $links, $settings_link );
    return $links;
}
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'add_post_title_to_image_alt_plugin_action_links' );
